@@ -1,11 +1,7 @@
-use crate::toxicblend_pb::Command as PB_Command;
-use crate::toxicblend_pb::Face as PB_Face;
-use crate::toxicblend_pb::KeyValuePair as PB_KeyValuePair;
-use crate::toxicblend_pb::Model as PB_Model;
-use crate::toxicblend_pb::Reply as PB_Reply;
-use crate::toxicblend_pb::Vertex as PB_Vertex;
-use crate::TBError;
-use boostvoronoi::geometry;
+use crate::{
+    type_utils, PB_Command, PB_Face, PB_KeyValuePair, PB_Model, PB_Reply, PB_Vertex, TBError,
+};
+use boostvoronoi as BV;
 use cgmath::{Angle, EuclideanSpace, SquareMatrix, Transform, UlpsEq};
 use itertools::Itertools;
 use linestring::{linestring_3d, linestring_3d::Plane};
@@ -34,7 +30,7 @@ fn transmute_to_u64(a: &cgmath::Point3<f64>) -> (u64, u64) {
 
 /// reformat the input into a useful structure
 #[allow(clippy::type_complexity)]
-pub fn parse_input(
+fn parse_input(
     input_pb_model: &PB_Model,
 ) -> Result<
     (
@@ -46,11 +42,11 @@ pub fn parse_input(
 > {
     let mut aabb = linestring_3d::Aabb3::<f64>::default();
     for v in input_pb_model.vertices.iter() {
-        aabb.update_point(&cgmath::Point3::new(v.x as f64, v.y as f64, v.z as f64))
+        aabb.update_point(cgmath::Point3::new(v.x as f64, v.y as f64, v.z as f64))
     }
 
     let plane =
-        Plane::get_plane_relaxed(&aabb, super::EPSILON, f64::default_max_ulps()).ok_or_else(|| {
+        Plane::get_plane_relaxed(aabb, super::EPSILON, f64::default_max_ulps()).ok_or_else(|| {
             let aabbe_d = aabb.get_high().unwrap() - aabb.get_low().unwrap();
             let aabbe_c = (aabb.get_high().unwrap().to_vec() + aabb.get_low().unwrap().to_vec())/2.0;
             TBError::InputNotPLane(format!(
@@ -97,7 +93,7 @@ pub fn parse_input(
 }
 
 /// Build the return model
-pub fn build_output_bp_model(
+fn build_output_bp_model(
     a_command: &PB_Command,
     shapes: Vec<(
         linestring::linestring_2d::LineStringSet2<f64>,
@@ -155,8 +151,8 @@ pub fn build_output_bp_model(
                     ));
                 }
                 // unwrap of first and last is safe now that we know there are at least 2 vertices in the list
-                let v0 = super::xy_to_3d(linestring.points().first().unwrap());
-                let v1 = super::xy_to_3d(linestring.points().last().unwrap());
+                let v0 = type_utils::xy_to_3d(linestring.points().first().unwrap());
+                let v1 = type_utils::xy_to_3d(linestring.points().last().unwrap());
                 let v0_key = transmute_to_u64(&v0);
                 let v0_index = *v_map.entry(v0_key).or_insert_with(|| {
                     let new_index = output_pb_model_vertices.len();
@@ -182,7 +178,7 @@ pub fn build_output_bp_model(
                             .skip(1)
                             .take(linestring.points().len() - 2)
                             .map(|p| {
-                                let v2 = super::xy_to_3d(p);
+                                let v2 = type_utils::xy_to_3d(p);
                                 let v2_key = transmute_to_u64(&v2);
                                 let v2_index = *v_map.entry(v2_key).or_insert_with(|| {
                                     let new_index = output_pb_model_vertices.len();
@@ -301,7 +297,8 @@ pub fn build_output_bp_model(
     })
 }
 
-pub fn command(
+/// Run the centerline command
+pub(crate) fn command(
     a_command: PB_Command,
     options: HashMap<String, String>,
 ) -> Result<PB_Reply, TBError> {
@@ -463,7 +460,7 @@ pub fn command(
     let lines = centerline::divide_into_shapes(edges, points)?;
     println!("-> get_transform_relaxed");
     let (_plane, transform, _voronoi_input_aabb) = centerline::get_transform_relaxed(
-        &total_aabb,
+        total_aabb,
         cmd_arg_max_voronoi_dimension,
         super::EPSILON,
         f64::default_max_ulps(),
@@ -505,18 +502,17 @@ pub fn command(
     let shapes = raw_data
         .into_par_iter()
         .map(|shape| {
-            let mut segments = Vec::<geometry::Line<i64>>::with_capacity(
-                shape.set().iter().map(|x| x.len()).sum(),
-            );
+            let mut segments =
+                Vec::<BV::Line<i64>>::with_capacity(shape.set().iter().map(|x| x.len()).sum());
             for lines in shape.set().iter() {
                 for lineseq in lines.as_lines_iter() {
-                    segments.push(geometry::Line::new(
+                    segments.push(BV::Line::new(
                         // boost voronoi only accepts integers as coordinates
-                        geometry::Point {
+                        BV::Point {
                             x: lineseq.start.x as i64,
                             y: lineseq.start.y as i64,
                         },
-                        geometry::Point {
+                        BV::Point {
                             x: lineseq.end.x as i64,
                             y: lineseq.end.y as i64,
                         },
