@@ -1,11 +1,7 @@
-use crate::toxicblend_pb::Command as PB_Command;
-use crate::toxicblend_pb::Face32 as PB_Face;
-use crate::toxicblend_pb::KeyValuePair as PB_KeyValuePair;
-use crate::toxicblend_pb::Matrix4x432 as PB_Matrix4x432;
-use crate::toxicblend_pb::Model32 as PB_Model;
-use crate::toxicblend_pb::Reply as PB_Reply;
-use crate::toxicblend_pb::Vertex32 as PB_Vertex;
-use crate::{type_utils::*, TBError};
+use crate::{
+    type_utils::*, PB_Command, PB_Face32, PB_KeyValuePair, PB_Matrix4x432, PB_Model32, PB_Reply,
+    PB_Vertex32, TBError,
+};
 use fast_surface_nets::{ndshape::ConstShape, surface_nets, SurfaceNetsBuffer};
 use ilattice::glam::{f32::Affine3A, IVec3, Mat3, Vec2, Vec3, Vec3A};
 use ilattice::prelude::*;
@@ -25,7 +21,7 @@ type Extent3i = Extent<IVec3>;
 
 #[allow(clippy::upper_case_acronyms)]
 #[derive(Debug, Copy, Clone)]
-pub enum Plane {
+pub(crate) enum Plane {
     XY,
     XZ,
     YZ,
@@ -112,6 +108,7 @@ fn build_voxel(
     vertices: Vec<(Vec2, f32)>,
     edges: Vec<(u32, u32)>,
     aabb: Extent<Vec3A>,
+    verbose: bool,
 ) -> Result<
     (
         f32, // <- voxel_size
@@ -126,14 +123,16 @@ fn build_voxel(
 
     let scale = (divisions / max_dimension) as f32;
 
-    println!(
-        "Voxelizing using divisions = {}, max dimension = {}, scale factor={} (max_dimension*scale={})",
-        divisions,
-        max_dimension,
-        scale,
-        (max_dimension as f32) * scale
-    );
-    println!();
+    if verbose {
+        println!(
+            "Voxelizing using divisions = {}, max dimension = {}, scale factor={} (max_dimension*scale={})",
+            divisions,
+            max_dimension,
+            scale,
+            (max_dimension as f32) * scale
+        );
+        println!();
+    }
 
     let rounded_cones: Vec<(RoundedCone, Extent3i)> = edges
         .into_par_iter()
@@ -195,13 +194,13 @@ fn build_voxel(
             })
             .collect()
     };
-
-    println!(
-        "process_chunks() duration: {:?} generated {} chunks",
-        now.elapsed(),
-        sdf_chunks.len()
-    );
-
+    if verbose {
+        println!(
+            "process_chunks() duration: {:?} generated {} chunks",
+            now.elapsed(),
+            sdf_chunks.len()
+        );
+    }
     Ok((1.0 / scale, sdf_chunks))
 }
 
@@ -334,7 +333,8 @@ pub(crate) fn build_output_bp_model(
     voxel_size: f32,
     mesh_buffers: Vec<(Vec3A, SurfaceNetsBuffer)>,
     cmd_arg_radius_axis: Plane,
-) -> Result<PB_Model, TBError> {
+    verbose: bool,
+) -> Result<PB_Model32, TBError> {
     let now = time::Instant::now();
 
     let (mut pb_vertices, mut pb_faces) = {
@@ -367,7 +367,7 @@ pub(crate) fn build_output_bp_model(
             // Z axis is the radius dimension, no swap
             {
                 for pv in mesh_buffer.positions.iter() {
-                    pb_vertices.push(PB_Vertex {
+                    pb_vertices.push(PB_Vertex32 {
                         x: (voxel_size * (pv[0] + vertex_offset.x)),
                         y: (voxel_size * (pv[1] + vertex_offset.y)),
                         z: (voxel_size * (pv[2] + vertex_offset.z)),
@@ -378,7 +378,7 @@ pub(crate) fn build_output_bp_model(
             // Y axis is the radius dimension, swap X,Y,Z to X,Z,Y
             {
                 for pv in mesh_buffer.positions.iter() {
-                    pb_vertices.push(PB_Vertex {
+                    pb_vertices.push(PB_Vertex32 {
                         x: (voxel_size * (pv[0] + vertex_offset.x)),
                         y: (voxel_size * (pv[2] + vertex_offset.z)),
                         z: (voxel_size * (pv[1] + vertex_offset.y)),
@@ -389,7 +389,7 @@ pub(crate) fn build_output_bp_model(
             // X axis is the radius dimension, swap X,Y,Z to Y,Z,X
             {
                 for pv in mesh_buffer.positions.iter() {
-                    pb_vertices.push(PB_Vertex {
+                    pb_vertices.push(PB_Vertex32 {
                         x: (voxel_size * (pv[2] + vertex_offset.z)),
                         y: (voxel_size * (pv[0] + vertex_offset.x)),
                         z: (voxel_size * (pv[1] + vertex_offset.y)),
@@ -402,34 +402,38 @@ pub(crate) fn build_output_bp_model(
         }
     }
 
-    println!(
-        "Vertex return model packaging duration: {:?}",
-        now.elapsed()
-    );
-
-    Ok(PB_Model {
+    if verbose {
+        println!(
+            "Vertex return model packaging duration: {:?}",
+            now.elapsed()
+        );
+    }
+    Ok(PB_Model32 {
         name: pb_model_name,
         world_orientation: pb_world,
         vertices: pb_vertices,
-        faces: vec![PB_Face { vertices: pb_faces }],
+        faces: vec![PB_Face32 { vertices: pb_faces }],
     })
 }
 
-pub fn command(
+/// Run the fsn_mavoxel command
+pub(crate) fn command(
     a_command: PB_Command,
     options: HashMap<String, String>,
+    verbose: bool,
 ) -> Result<PB_Reply, TBError> {
     let now = time::Instant::now();
-
-    println!(
-        r#"___________                _____     _____  ____   ___                     __
+    if verbose {
+        println!(
+            r#"___________                _____     _____  ____   ___                     __
 \_   _____/ ______ ____   /     \   /  _  \ \   \ /  / ____ ___  ___ ____ |  |
   |  ___)  /  ___//    \ /  \ /  \ /  /_\  \ \   \  / / __ \\  \/  // __ \|  |
   |  \__   \___ \|   |  \    \    \    |    \ \    / (  \_\ )\    /\  ___/_  |__
  /___  /  /____  \___|  /____/\_  /____|__  /  \  /   \____//__/\_ \\___  /____/
      \/        \/     \/        \/        \/    \/                \/    \/      "#
-    );
-
+        );
+        //crate::print_command(&a_command);
+    }
     if a_command.models32.len() > 1 {
         return Err(TBError::InvalidInputData(format!(
             "This operation only supports one model as input:{}",
@@ -458,27 +462,29 @@ pub fn command(
         .map_err(|_| {
             TBError::InvalidInputData("Could not parse the DIVISIONS parameter".to_string())
         })?;
-    if !(9.9..400.1).contains(&cmd_arg_divisions) {
+    if !(9.9..600.1).contains(&cmd_arg_divisions) {
         return Err(TBError::InvalidInputData(format!(
             "The valid range of DIVISIONS is [{}..{}[% :({})",
-            10, 400, cmd_arg_divisions
+            10, 600, cmd_arg_divisions
         )));
     }
 
-    for model in a_command.models32.iter() {
-        println!("model.name:{:?}, ", model.name);
-        println!("model.vertices:{:?}, ", model.vertices.len());
-        println!("model.faces:{:?}, ", model.faces.len());
-        println!(
-            "model.world_orientation:{:?}, ",
-            model.world_orientation.as_ref().map_or(0, |_| 16)
-        );
-        println!("Voxel divisions:{:?} ", cmd_arg_divisions);
-        println!(
-            "2d point axis:{:?}. Radius is the third axis",
-            cmd_arg_radius_axis
-        );
-        println!();
+    if verbose {
+        for model in a_command.models32.iter() {
+            println!("model.name:{:?}, ", model.name);
+            println!("model.vertices:{:?}, ", model.vertices.len());
+            println!("model.faces:{:?}, ", model.faces.len());
+            println!(
+                "model.world_orientation:{:?}, ",
+                model.world_orientation.as_ref().map_or(0, |_| 16)
+            );
+            println!("Voxel divisions:{:?} ", cmd_arg_divisions);
+            println!(
+                "2d point axis:{:?}. Radius is the third axis",
+                cmd_arg_radius_axis
+            );
+            println!();
+        }
     }
 
     let unpacked = parse_input_pb_model(a_command, cmd_arg_radius_axis)?;
@@ -487,6 +493,7 @@ pub fn command(
         unpacked.vertices,
         unpacked.edges,
         unpacked.aabb,
+        verbose,
     )?;
     let packed_faces_model = build_output_bp_model(
         unpacked.model_name,
@@ -494,22 +501,24 @@ pub fn command(
         voxel_size,
         mesh,
         cmd_arg_radius_axis,
+        verbose,
     )?;
-    println!(
-        "Total number of vertices: {}",
-        packed_faces_model.vertices.len()
-    );
-
-    println!(
-        "Total number of triangles: {}",
-        packed_faces_model
-            .faces
-            .iter()
-            .map(|x| x.vertices.len())
-            .sum::<usize>()
-            / 3
-    );
+    if verbose {
+        println!(
+            "Total number of vertices: {}",
+            packed_faces_model.vertices.len()
+        );
 
+        println!(
+            "Total number of triangles: {}",
+            packed_faces_model
+                .faces
+                .iter()
+                .map(|x| x.vertices.len())
+                .sum::<usize>()
+                / 3
+        );
+    }
     let reply = PB_Reply {
         options: vec![
             PB_KeyValuePair {
@@ -526,9 +535,11 @@ pub fn command(
                 value: "True".to_string(),
             },
         ],
-        models: Vec::with_capacity(0),
+        models: Vec::default(),
         models32: vec![packed_faces_model],
     };
-    println!("total duration: {:?}", now.elapsed());
+    if verbose {
+        println!("total duration: {:?}", now.elapsed());
+    }
     Ok(reply)
 }
