@@ -1,11 +1,8 @@
-use crate::toxicblend_pb::Command as PB_Command;
-use crate::toxicblend_pb::Face32 as PB_Face;
-use crate::toxicblend_pb::KeyValuePair as PB_KeyValuePair;
-use crate::toxicblend_pb::Matrix4x432 as PB_Matrix4x432;
-use crate::toxicblend_pb::Model32 as PB_Model;
-use crate::toxicblend_pb::Reply as PB_Reply;
-use crate::toxicblend_pb::Vertex32 as PB_Vertex;
-use crate::{type_utils::*, TBError};
+use crate::{
+    type_utils::*, PB_Command, PB_Face32, PB_KeyValuePair, PB_Matrix4x432, PB_Model32, PB_Reply,
+    PB_Vertex32, TBError,
+};
+
 use fast_surface_nets::{ndshape::ConstShape, surface_nets, SurfaceNetsBuffer};
 use ilattice::glam::{IVec3, Vec3A};
 use ilattice::prelude::*;
@@ -27,7 +24,7 @@ type Extent3i = Extent<IVec3>;
 /// unpack the input PB_Model
 #[allow(clippy::type_complexity)]
 fn parse_input_pb_model(
-    obj: &PB_Model,
+    obj: &PB_Model32,
 ) -> Result<(Vec<(u32, u32)>, linestring::linestring_3d::Aabb3<f32>), TBError> {
     let mut aabb = linestring::linestring_3d::Aabb3::<f32>::default();
     if obj.vertices.len() >= u32::MAX as usize {
@@ -37,7 +34,7 @@ fn parse_input_pb_model(
         )));
     }
     for vertex in obj.vertices.iter() {
-        aabb.update_point(&cgmath::Point3 {
+        aabb.update_point(cgmath::Point3 {
             x: vertex.x,
             y: vertex.y,
             z: vertex.z,
@@ -67,9 +64,10 @@ fn parse_input_pb_model(
 fn build_voxel(
     radius_multiplier: f32,
     divisions: f32,
-    vertices: &[PB_Vertex],
+    vertices: &[PB_Vertex32],
     edges: Vec<(u32, u32)>,
     aabb: linestring::linestring_3d::Aabb3<f32>,
+    verbose: bool,
 ) -> Result<
     (
         f32, // <- voxel_size
@@ -83,20 +81,21 @@ fn build_voxel(
     let radius = max_dimension * radius_multiplier; // unscaled
     let scale = (divisions / max_dimension) as f32;
 
-    println!(
-        "Voxelizing using tube radius. {} = {}*{}*{}",
-        radius, max_dimension, radius_multiplier, scale
-    );
-
-    println!(
-        "Voxelizing using divisions = {}, max dimension = {}, scale factor={} (max_dimension*scale={})",
-        divisions,
-        max_dimension,
-        scale,
-        (max_dimension as f32) * scale
-    );
-    println!();
+    if verbose {
+        println!(
+            "Voxelizing using tube radius. {} = {}*{}*{}",
+            radius, max_dimension, radius_multiplier, scale
+        );
 
+        println!(
+            "Voxelizing using divisions = {}, max dimension = {}, scale factor={} (max_dimension*scale={})",
+            divisions,
+            max_dimension,
+            scale,
+            (max_dimension as f32) * scale
+        );
+        println!();
+    }
     let vertices: Vec<Vec3A> = vertices
         .iter()
         .map(|v| Vec3A::new(v.x, v.y, v.z) * scale)
@@ -134,11 +133,13 @@ fn build_voxel(
             .collect()
     };
 
-    println!(
-        "process_chunks() duration: {:?} generated {} chunks",
-        now.elapsed(),
-        sdf_chunks.len()
-    );
+    if verbose {
+        println!(
+            "process_chunks() duration: {:?} generated {} chunks",
+            now.elapsed(),
+            sdf_chunks.len()
+        );
+    }
 
     Ok((1.0 / scale, sdf_chunks))
 }
@@ -255,7 +256,8 @@ pub(crate) fn build_output_bp_model(
     pb_world: Option<PB_Matrix4x432>,
     voxel_size: f32,
     mesh_buffers: Vec<(Vec3A, SurfaceNetsBuffer)>,
-) -> Result<PB_Model, TBError> {
+    verbose: bool,
+) -> Result<PB_Model32, TBError> {
     let now = time::Instant::now();
 
     let (mut pb_vertices, mut pb_faces) = {
@@ -284,7 +286,7 @@ pub(crate) fn build_output_bp_model(
 
         // vertices this far inside a chunk should (probably?) not be used outside this chunk.
         for pv in mesh_buffer.positions.iter() {
-            pb_vertices.push(PB_Vertex {
+            pb_vertices.push(PB_Vertex32 {
                 x: (voxel_size * (pv[0] + vertex_offset.x)),
                 y: (voxel_size * (pv[1] + vertex_offset.y)),
                 z: (voxel_size * (pv[2] + vertex_offset.z)),
@@ -295,34 +297,40 @@ pub(crate) fn build_output_bp_model(
         }
     }
 
-    println!(
-        "Vertex return model packaging duration: {:?}",
-        now.elapsed()
-    );
+    if verbose {
+        println!(
+            "Vertex return model packaging duration: {:?}",
+            now.elapsed()
+        );
+    }
 
-    Ok(PB_Model {
+    Ok(PB_Model32 {
         name: pb_model_name,
         world_orientation: pb_world,
         vertices: pb_vertices,
-        faces: vec![PB_Face { vertices: pb_faces }],
+        faces: vec![PB_Face32 { vertices: pb_faces }],
     })
 }
 
-pub fn command(
+/// Run the fsn_voxel command
+pub(crate) fn command(
     a_command: PB_Command,
     options: HashMap<String, String>,
+    verbose: bool,
 ) -> Result<PB_Reply, TBError> {
     let now = time::Instant::now();
 
-    println!(
-        r#"___________         ____   ____                 .__
+    if verbose {
+        println!(
+            r#"___________         ____   ____                 .__
 \_   _____/_____ ___\   \ /   /______  ___ ____ |  |
  |    __)/  ___//    \   Y   /  _ \  \/  // __ \|  |
  |     \ \___ \|   |  \     (  <_> >    <\  ___/|  |__
  \___  //____  >___|  /\___/ \____/__/\_ \\___  >____/
      \/      \/     \/                  \/    \/"#
-    );
-
+        );
+        //crate::print_command(&a_command);
+    }
     if a_command.models32.len() > 1 {
         return Err(TBError::InvalidInputData(format!(
             "This operation only supports one model as input:{}",
@@ -357,17 +365,19 @@ pub fn command(
         )));
     }
 
-    for model in a_command.models32.iter() {
-        println!("model.name:{:?}, ", model.name);
-        println!("model.vertices:{:?}, ", model.vertices.len());
-        println!("model.faces:{:?}, ", model.faces.len());
-        println!(
-            "model.world_orientation:{:?}, ",
-            model.world_orientation.as_ref().map_or(0, |_| 16)
-        );
-        println!("Tube radius:{:?} multiplier ", cmd_arg_radius_multiplier);
-        println!("Voxel divisions:{:?} ", cmd_arg_divisions);
-        println!();
+    if verbose {
+        for model in a_command.models32.iter() {
+            println!("model.name:{:?}, ", model.name);
+            println!("model.vertices:{:?}, ", model.vertices.len());
+            println!("model.faces:{:?}, ", model.faces.len());
+            println!(
+                "model.world_orientation:{:?}, ",
+                model.world_orientation.as_ref().map_or(0, |_| 16)
+            );
+            println!("Tube radius:{:?} multiplier ", cmd_arg_radius_multiplier);
+            println!("Voxel divisions:{:?} ", cmd_arg_divisions);
+            println!();
+        }
     }
 
     let (edges, aabb) = parse_input_pb_model(&a_command.models32[0])?;
@@ -377,27 +387,31 @@ pub fn command(
         &a_command.models32[0].vertices,
         edges,
         aabb,
+        verbose,
     )?;
     let packed_faces_model = build_output_bp_model(
         a_command.command.clone(),
         a_command.models32[0].world_orientation.clone(),
         voxel_size,
         mesh,
+        verbose,
     )?;
-    println!(
-        "Total number of vertices: {}",
-        packed_faces_model.vertices.len()
-    );
+    if verbose {
+        println!(
+            "Total number of vertices: {}",
+            packed_faces_model.vertices.len()
+        );
 
-    println!(
-        "Total number of triangles: {}",
-        packed_faces_model
-            .faces
-            .iter()
-            .map(|x| x.vertices.len())
-            .sum::<usize>()
-            / 3
-    );
+        println!(
+            "Total number of triangles: {}",
+            packed_faces_model
+                .faces
+                .iter()
+                .map(|x| x.vertices.len())
+                .sum::<usize>()
+                / 3
+        );
+    }
 
     let reply = PB_Reply {
         options: vec![
@@ -418,6 +432,8 @@ pub fn command(
         models: Vec::with_capacity(0),
         models32: vec![packed_faces_model],
     };
-    println!("total duration: {:?}", now.elapsed());
+    if verbose {
+        println!("total duration: {:?}", now.elapsed());
+    }
     Ok(reply)
 }
