@@ -1,10 +1,6 @@
-use crate::toxicblend_pb::Command as PB_Command;
-use crate::toxicblend_pb::Face as PB_Face;
-use crate::toxicblend_pb::KeyValuePair as PB_KeyValuePair;
-use crate::toxicblend_pb::Model as PB_Model;
-use crate::toxicblend_pb::Reply as PB_Reply;
-use crate::toxicblend_pb::Vertex as PB_Vertex;
-use crate::{GrowingVob, TBError};
+use crate::{
+    GrowingVob, PB_Command, PB_Face, PB_KeyValuePair, PB_Model, PB_Reply, PB_Vertex, TBError,
+};
 use cgmath::EuclideanSpace;
 use cgmath::UlpsEq;
 use itertools::Itertools;
@@ -32,10 +28,10 @@ fn transmute_to_u64(a: cgmath::Point2<f64>) -> (u64, u64) {
 fn knife_intersect(input_pb_model: &PB_Model) -> Result<PB_Model, TBError> {
     let mut aabb = linestring::linestring_3d::Aabb3::<f64>::default();
     for v in input_pb_model.vertices.iter() {
-        aabb.update_point(&cgmath::Point3::new(v.x as f64, v.y as f64, v.z as f64))
+        aabb.update_point(cgmath::Point3::new(v.x as f64, v.y as f64, v.z as f64))
     }
 
-    let plane = Plane::get_plane_relaxed(&aabb, super::EPSILON, f64::default_max_ulps()).ok_or_else(|| {
+    let plane = Plane::get_plane_relaxed(aabb, super::EPSILON, f64::default_max_ulps()).ok_or_else(|| {
         let aabbe_d = aabb.get_high().unwrap() - aabb.get_low().unwrap();
         let aabbe_c = (aabb.get_high().unwrap().to_vec() + aabb.get_low().unwrap().to_vec())/2.0;
         TBError::InputNotPLane(format!(
@@ -66,7 +62,7 @@ fn knife_intersect(input_pb_model: &PB_Model) -> Result<PB_Model, TBError> {
                 y: v.z as f64,
             })
             .collect(),
-        Plane::ZY => input_pb_model
+        Plane::YZ => input_pb_model
             .vertices
             .iter()
             .map(|v| cgmath::Point2 {
@@ -162,7 +158,7 @@ fn knife_intersect(input_pb_model: &PB_Model) -> Result<PB_Model, TBError> {
                         y: 0.0,
                         z: new_vertex.y as f64,
                     },
-                    Plane::ZY => PB_Vertex {
+                    Plane::YZ => PB_Vertex {
                         x: 0.0,
                         y: new_vertex.y as f64,
                         z: new_vertex.x as f64,
@@ -208,7 +204,8 @@ fn knife_intersect(input_pb_model: &PB_Model) -> Result<PB_Model, TBError> {
     Ok(output_pb_model)
 }
 
-pub fn command(
+/// Run the knife_intersect command
+pub(crate) fn command(
     a_command: PB_Command,
     _options: HashMap<String, String>,
 ) -> Result<PB_Reply, TBError> {
