@@ -1,13 +1,6 @@
-use crate::toxicblend_pb::Command as PB_Command;
-use crate::toxicblend_pb::Face as PB_Face;
-use crate::toxicblend_pb::KeyValuePair as PB_KeyValuePair;
-use crate::toxicblend_pb::Model as PB_Model;
-use crate::toxicblend_pb::Reply as PB_Reply;
-use crate::toxicblend_pb::Vertex as PB_Vertex;
-use crate::{
-    lsystems_3d::{Turtle, TurtleCommand, TurtleRules},
-    TBError,
-};
+use crate::{PB_Command, PB_Face, PB_KeyValuePair, PB_Model, PB_Reply, PB_Vertex, TBError};
+
+use crate::lsystems_3d::{Turtle, TurtleCommand, TurtleRules};
 
 use cgmath::{EuclideanSpace, Rad};
 use std::collections::HashMap;
@@ -467,7 +460,7 @@ fn build_output_bp_model(
         let i0 = *vertices_map.entry(key).or_insert_with(|| {
             let n = pb_vertices.len();
 
-            src_aabb.update_point(&p0);
+            src_aabb.update_point(p0);
             pb_vertices.push(PB_Vertex {
                 x: p0.x,
                 y: p0.y,
@@ -480,7 +473,7 @@ fn build_output_bp_model(
         let i1 = *vertices_map.entry(key).or_insert_with(|| {
             let n = pb_vertices.len();
 
-            src_aabb.update_point(&p1);
+            src_aabb.update_point(p1);
             pb_vertices.push(PB_Vertex {
                 x: p1.x,
                 y: p1.y,
@@ -535,7 +528,8 @@ fn build_output_bp_model(
     })
 }
 
-pub fn command(
+/// Run the lsystems command
+pub(crate) fn command(
     a_command: PB_Command,
     options: HashMap<String, String>,
 ) -> Result<PB_Reply, TBError> {
