@@ -1,11 +1,8 @@
-use crate::toxicblend_pb::Command as PB_Command;
-use crate::toxicblend_pb::Face32 as PB_Face;
-use crate::toxicblend_pb::KeyValuePair as PB_KeyValuePair;
-use crate::toxicblend_pb::Matrix4x432 as PB_Matrix4x432;
-use crate::toxicblend_pb::Model32 as PB_Model;
-use crate::toxicblend_pb::Reply as PB_Reply;
-use crate::toxicblend_pb::Vertex32 as PB_Vertex;
-use crate::TBError;
+use crate::{
+    PB_Command, PB_Face32, PB_KeyValuePair, PB_Matrix4x432, PB_Model32, PB_Reply, PB_Vertex32,
+    TBError,
+};
+
 use glam_saft::Vec3;
 use saft::BoundingBox;
 use std::collections::HashMap;
@@ -13,7 +10,7 @@ use std::time;
 
 /// unpack the input PB_Model
 #[allow(clippy::type_complexity)]
-pub fn parse_input_pb_model(obj: &PB_Model) -> Result<(Vec<(u32, u32)>, BoundingBox), TBError> {
+fn parse_input_pb_model(obj: &PB_Model32) -> Result<(Vec<(u32, u32)>, BoundingBox), TBError> {
     if obj.vertices.len() >= u32::MAX as usize {
         return Err(TBError::Overflow(format!(
             "Input data contains too many vertices. {}",
@@ -49,9 +46,10 @@ pub fn parse_input_pb_model(obj: &PB_Model) -> Result<(Vec<(u32, u32)>, Bounding
 fn build_voxel(
     radius_multiplier: f32,
     divisions: f32,
-    vertices: &[PB_Vertex],
+    vertices: &[PB_Vertex32],
     edges: Vec<(u32, u32)>,
     aabb: BoundingBox,
+    verbose: bool,
 ) -> Result<
     (
         f32, // <- voxel_size
@@ -66,27 +64,29 @@ fn build_voxel(
     let thickness = radius * 2.0; // unscaled
     let scale = (divisions / max_dimension) as f32;
 
-    println!(
-        "Voxelizing using tube thickness. {} = {}*{}*{}",
-        thickness, max_dimension, radius_multiplier, scale
-    );
+    if verbose {
+        println!(
+            "Voxelizing using tube thickness. {} = {}*{}*{}",
+            thickness, max_dimension, radius_multiplier, scale
+        );
 
-    println!(
-        "Voxelizing using divisions = {}, max dimension = {}, scale factor={} (max_dimension*scale={})",
-        divisions,
-        max_dimension,
-        scale,
-        (max_dimension as f32) * scale
-    );
-    println!();
-
-    println!("aabb.high:{:?}", aabb.max);
-    println!("aabb.low:{:?}", aabb.min);
-    println!("delta:{:?}", aabb.max - aabb.min);
+        println!(
+            "Voxelizing using divisions = {}, max dimension = {}, scale factor={} (max_dimension*scale={})",
+            divisions,
+            max_dimension,
+            scale,
+            (max_dimension as f32) * scale
+        );
+        println!();
 
+        println!("aabb.high:{:?}", aabb.max);
+        println!("aabb.low:{:?}", aabb.min);
+        println!("delta:{:?}", aabb.max - aabb.min);
+    }
     let mean_resolution = max_dimension * scale;
-    println!("mean_resolution:{:?}", mean_resolution);
-
+    if verbose {
+        println!("mean_resolution:{:?}", mean_resolution);
+    }
     let mesh_options = saft::MeshOptions {
         mean_resolution,
         max_resolution: mean_resolution,
@@ -110,8 +110,9 @@ fn build_voxel(
     let root = graph.op_union_multi(capsules);
     let mesh = saft::mesh_from_sdf(&graph, root, mesh_options)?;
 
-    println!("mesh_from_sdf() duration: {:?}", now.elapsed());
-
+    if verbose {
+        println!("mesh_from_sdf() duration: {:?}", now.elapsed());
+    }
     Ok((1.0 / scale, mesh))
 }
 
@@ -121,41 +122,44 @@ pub(crate) fn build_output_bp_model(
     pb_world: Option<PB_Matrix4x432>,
     voxel_size: f32,
     mesh: saft::TriangleMesh,
-) -> Result<PB_Model, TBError> {
-    let pb_vertices: Vec<PB_Vertex> = mesh
+) -> Result<PB_Model32, TBError> {
+    let pb_vertices: Vec<PB_Vertex32> = mesh
         .positions
         .iter()
-        .map(|v| PB_Vertex {
+        .map(|v| PB_Vertex32 {
             x: (voxel_size * v[0]),
             y: (voxel_size * v[1]),
             z: (voxel_size * v[2]),
         })
         .collect();
 
-    Ok(PB_Model {
+    Ok(PB_Model32 {
         name: pb_model_name,
         world_orientation: pb_world,
         vertices: pb_vertices,
-        faces: vec![PB_Face {
+        faces: vec![PB_Face32 {
             vertices: mesh.indices,
         }],
     })
 }
 
-pub fn command(
+/// Run the saft_voxel command
+pub(crate) fn command(
     a_command: PB_Command,
     options: HashMap<String, String>,
+    verbose: bool,
 ) -> Result<PB_Reply, TBError> {
     let now = time::Instant::now();
-    println!(
-        r#"  _________       _____  __ ____   ____                 .__
+    if verbose {
+        println!(
+            r#"  _________       _____  __ ____   ____                 .__
  /   _____/____ _/ ____\/  |\   \ /   /______  ___ ____ |  |
  \_____  \\__  \\   __\\   __\   Y   /  _ \  \/  // __ \|  |
  /        \/ __ \|  |   |  |  \     (  <_> >    <\  ___/|  |__
 /_______  (____  /__|   |__|   \___/ \____/__/\_ \\___  >____/
         \/     \/                               \/    \/"#
-    );
-
+        );
+    }
     if a_command.models32.len() > 1 {
         return Err(TBError::InvalidInputData(format!(
             "This operation only supports one model as input:{}",
@@ -190,19 +194,20 @@ pub fn command(
         )));
     }
 
-    for model in a_command.models32.iter() {
-        println!("model.name:{:?}, ", model.name);
-        println!("model.vertices:{:?}, ", model.vertices.len());
-        println!("model.faces:{:?}, ", model.faces.len());
-        println!(
-            "model.world_orientation:{:?}, ",
-            model.world_orientation.as_ref().map_or(0, |_| 16)
-        );
-        println!("Tube radius:{:?} multiplier ", cmd_arg_radius_multiplier);
-        println!("Voxel divisions:{:?} ", cmd_arg_divisions);
-        println!();
+    if verbose {
+        for model in a_command.models32.iter() {
+            println!("model.name:{:?}, ", model.name);
+            println!("model.vertices:{:?}, ", model.vertices.len());
+            println!("model.faces:{:?}, ", model.faces.len());
+            println!(
+                "model.world_orientation:{:?}, ",
+                model.world_orientation.as_ref().map_or(0, |_| 16)
+            );
+            println!("Tube radius:{:?} multiplier ", cmd_arg_radius_multiplier);
+            println!("Voxel divisions:{:?} ", cmd_arg_divisions);
+            println!();
+        }
     }
-
     let (edges, aabb) = parse_input_pb_model(&a_command.models32[0])?;
     let (voxel_size, mesh) = build_voxel(
         cmd_arg_radius_multiplier,
@@ -210,6 +215,7 @@ pub fn command(
         &a_command.models32[0].vertices,
         edges,
         aabb,
+        verbose,
     )?;
     let packed_faces_model = build_output_bp_model(
         a_command.command.clone(),
@@ -217,21 +223,22 @@ pub fn command(
         voxel_size,
         mesh,
     )?;
-    println!(
-        "Total number of vertices: {}",
-        packed_faces_model.vertices.len()
-    );
-
-    println!(
-        "Total number of triangles: {}",
-        packed_faces_model
-            .faces
-            .iter()
-            .map(|x| x.vertices.len())
-            .sum::<usize>()
-            / 3
-    );
+    if verbose {
+        println!(
+            "Total number of vertices: {}",
+            packed_faces_model.vertices.len()
+        );
 
+        println!(
+            "Total number of triangles: {}",
+            packed_faces_model
+                .faces
+                .iter()
+                .map(|x| x.vertices.len())
+                .sum::<usize>()
+                / 3
+        );
+    }
     let reply = PB_Reply {
         options: vec![
             PB_KeyValuePair {
@@ -246,6 +253,8 @@ pub fn command(
         models: Vec::with_capacity(0),
         models32: vec![packed_faces_model],
     };
-    println!("total duration: {:?}", now.elapsed());
+    if verbose {
+        println!("total duration: {:?}", now.elapsed());
+    }
     Ok(reply)
 }
