@@ -1,10 +1,5 @@
-use crate::toxicblend_pb::Command as PB_Command;
-use crate::toxicblend_pb::Face as PB_Face;
-use crate::toxicblend_pb::KeyValuePair as PB_KeyValuePair;
-use crate::toxicblend_pb::Model as PB_Model;
-use crate::toxicblend_pb::Reply as PB_Reply;
-use crate::toxicblend_pb::Vertex as PB_Vertex;
-use crate::TBError;
+use crate::{PB_Command, PB_Face, PB_KeyValuePair, PB_Model, PB_Reply, PB_Vertex, TBError};
+
 use itertools::Itertools;
 use linestring::linestring_3d;
 use rayon::prelude::*;
@@ -12,7 +7,7 @@ use std::collections::HashMap;
 
 /// Simplify the model into a sequence of connected vertices.
 /// The end and start points has duplicate-checked vertex numbers, the 'in the middle' vertexes do not.
-pub fn find_linestrings(
+fn find_linestrings(
     obj: &PB_Model,
 ) -> Result<Vec<(usize, linestring_3d::LineString3<f64>, usize)>, TBError> {
     let mut linestrings = Vec::<(usize, linestring_3d::LineString3<f64>, usize)>::new();
@@ -301,7 +296,7 @@ fn simplify_rdp_percent(
 ) -> Result<Vec<(usize, linestring_3d::LineString3<f64>, usize)>, TBError> {
     let mut aabb = linestring::linestring_3d::Aabb3::<f64>::default();
     for v in pb_model.vertices.iter() {
-        aabb.update_point(&cgmath::Point3::new(v.x, v.y, v.z))
+        aabb.update_point(cgmath::Point3::new(v.x, v.y, v.z))
     }
     let dimension = aabb.get_high().unwrap() - aabb.get_low().unwrap();
     let dimension = dimension.x.max(dimension.y).max(dimension.z);
@@ -411,7 +406,8 @@ fn build_bp_model(
     //return Err(TBError::InvalidData(format!("not implemented")));
 }
 
-pub fn command(
+/// Run the simplify command
+pub(crate) fn command(
     a_command: PB_Command,
     options: HashMap<String, String>,
 ) -> Result<PB_Reply, TBError> {
