@@ -1,14 +1,9 @@
-use crate::toxicblend_pb::Command as PB_Command;
-use crate::toxicblend_pb::Face as PB_Face;
-use crate::toxicblend_pb::KeyValuePair as PB_KeyValuePair;
-use crate::toxicblend_pb::Model as PB_Model;
-use crate::toxicblend_pb::Reply as PB_Reply;
-use crate::toxicblend_pb::Vertex as PB_Vertex;
-use crate::{GrowingVob, TBError};
-use boostvoronoi::builder as VB;
-use boostvoronoi::diagram as VD;
-use boostvoronoi::geometry;
-use boostvoronoi::visual_utils as VU;
+use crate::{
+    type_utils, GrowingVob, PB_Command, PB_Face, PB_KeyValuePair, PB_Model, PB_Reply, PB_Vertex,
+    TBError,
+};
+
+use boostvoronoi as BV;
 use cgmath::{ulps_eq, EuclideanSpace, SquareMatrix, Transform, UlpsEq};
 use itertools::Itertools;
 use linestring::linestring_2d::Aabb2;
@@ -34,9 +29,9 @@ fn transmute_to_u64(a: &cgmath::Point2<f64>) -> (u64, u64) {
 
 /// Helper structs that build PB buffer from Diagram
 struct DiagramHelper {
-    diagram: VD::Diagram<i64, f64>,
-    vertices: Vec<geometry::Point<i64>>,
-    segments: Vec<geometry::Line<i64>>,
+    diagram: BV::Diagram<f64>,
+    vertices: Vec<BV::Point<i64>>,
+    segments: Vec<BV::Line<i64>>,
     aabb: Aabb2<f64>,
     rejected_edges: Option<vob::Vob<u32>>,
     discrete_distance: f64,
@@ -109,7 +104,7 @@ impl DiagramHelper {
         let max_dist = max_dist.x.max(max_dist.y);
         let max_dist = self.discrete_distance * max_dist;
         //println!("max distance = {}",max_dist);
-        let dummy_affine = boostvoronoi::visual_utils::SimpleAffine::default();
+        let dummy_affine = BV::SimpleAffine::default();
 
         let mut already_drawn: vob::Vob<u32> = vob::Vob::<u32>::fill(self.diagram.edges().len());
 
@@ -119,7 +114,7 @@ impl DiagramHelper {
             .unwrap_or_else(|| vob::Vob::<u32>::fill(self.diagram.edges().len()));
 
         for it in self.diagram.edges().iter().enumerate() {
-            let edge_id = VD::EdgeIndex(it.0);
+            let edge_id = BV::EdgeIndex(it.0);
             let edge = it.1.get();
             if (self.remove_secondary_edges && edge.is_secondary())
                 || already_drawn.get_f(edge_id.0)
@@ -151,7 +146,7 @@ impl DiagramHelper {
                     self.sample_curved_edge(
                         max_dist,
                         &dummy_affine,
-                        VD::EdgeIndex(it.0),
+                        BV::EdgeIndex(it.0),
                         &mut samples,
                     )?;
                 }
@@ -209,8 +204,8 @@ impl DiagramHelper {
     fn sample_curved_edge(
         &self,
         max_dist: f64,
-        dummy_affine: &VU::SimpleAffine<i64, f64>,
-        edge_id: VD::EdgeIndex,
+        dummy_affine: &BV::SimpleAffine<f64>,
+        edge_id: BV::EdgeIndex,
         sampled_edge: &mut Vec<[f64; 2]>,
     ) -> Result<(), TBError> {
         let cell_id = self.diagram.edge_get_cell(edge_id)?;
@@ -228,25 +223,19 @@ impl DiagramHelper {
         } else {
             self.retrieve_segment(cell_id)?
         };
-        VU::VoronoiVisualUtils::<i64, f64>::discretize(
-            &point,
-            segment,
-            max_dist,
-            dummy_affine,
-            sampled_edge,
-        );
+        BV::VoronoiVisualUtils::discretize(&point, segment, max_dist, dummy_affine, sampled_edge);
         Ok(())
     }
 
     /// Retrieves a point from the voronoi input in the order it was presented to
     /// the voronoi builder
     #[inline(always)]
-    fn retrieve_point(&self, cell_id: VD::CellIndex) -> Result<geometry::Point<i64>, TBError> {
+    fn retrieve_point(&self, cell_id: BV::CellIndex) -> Result<BV::Point<i64>, TBError> {
         let (index, cat) = self.diagram.get_cell(cell_id)?.get().source_index_2();
         Ok(match cat {
-            VD::SourceCategory::SinglePoint => self.vertices[index],
-            VD::SourceCategory::SegmentStart => self.segments[index - self.vertices.len()].start,
-            VD::SourceCategory::Segment | VD::SourceCategory::SegmentEnd => {
+            BV::SourceCategory::SinglePoint => self.vertices[index],
+            BV::SourceCategory::SegmentStart => self.segments[index - self.vertices.len()].start,
+            BV::SourceCategory::Segment | BV::SourceCategory::SegmentEnd => {
                 self.segments[index - self.vertices.len()].end
             }
         })
@@ -255,7 +244,7 @@ impl DiagramHelper {
     /// Retrieves a segment from the voronoi input in the order it was presented to
     /// the voronoi builder
     #[inline(always)]
-    fn retrieve_segment(&self, cell_id: VD::CellIndex) -> Result<&geometry::Line<i64>, TBError> {
+    fn retrieve_segment(&self, cell_id: BV::CellIndex) -> Result<&BV::Line<i64>, TBError> {
         let cell = self.diagram.get_cell(cell_id)?.get();
         let index = cell.source_index() - self.vertices.len();
         Ok(&self.segments[index])
@@ -263,7 +252,7 @@ impl DiagramHelper {
 
     fn clip_infinite_edge(
         &self,
-        edge_id: VD::EdgeIndex,
+        edge_id: BV::EdgeIndex,
         clipped_edge: &mut Vec<[f64; 2]>,
     ) -> Result<(), TBError> {
         let edge = self.diagram.get_edge(edge_id)?;
@@ -347,8 +336,8 @@ fn parse_input(
     cmd_arg_max_voronoi_dimension: f64,
 ) -> Result<
     (
-        Vec<geometry::Point<i64>>,
-        Vec<geometry::Line<i64>>,
+        Vec<BV::Point<i64>>,
+        Vec<BV::Line<i64>>,
         Aabb2<f64>,
         cgmath::Matrix4<f64>,
     ),
@@ -356,11 +345,11 @@ fn parse_input(
 > {
     let mut aabb = linestring::linestring_3d::Aabb3::<f64>::default();
     for v in input_pb_model.vertices.iter() {
-        aabb.update_point(&cgmath::Point3::new(v.x as f64, v.y as f64, v.z as f64))
+        aabb.update_point(cgmath::Point3::new(v.x as f64, v.y as f64, v.z as f64))
     }
 
     let (plane, transform, vor_aabb)= centerline::get_transform_relaxed(
-        &aabb,
+        aabb,
         cmd_arg_max_voronoi_dimension,
         super::EPSILON,
         f64::default_max_ulps(),
@@ -379,17 +368,17 @@ fn parse_input(
     println!("voronoi: data was in plane:{:?} aabb:{:?}", plane, aabb);
     //println!("input Lines:{:?}", input_pb_model.vertices);
 
-    let mut vor_lines = Vec::<geometry::Line<i64>>::with_capacity(input_pb_model.faces.len());
-    let vor_vertices: Vec<geometry::Point<i64>> = input_pb_model
+    let mut vor_lines = Vec::<BV::Line<i64>>::with_capacity(input_pb_model.faces.len());
+    let vor_vertices: Vec<BV::Point<i64>> = input_pb_model
         .vertices
         .iter()
         .map(|vertex| {
-            let p = super::xy_to_2d(&transform.transform_point(cgmath::Point3 {
+            let p = type_utils::xy_to_2d(&transform.transform_point(cgmath::Point3 {
                 x: vertex.x,
                 y: vertex.y,
                 z: vertex.z,
             }));
-            geometry::Point {
+            BV::Point {
                 x: p.x as i64,
                 y: p.y as i64,
             }
@@ -404,7 +393,7 @@ fn parse_input(
                 let v0 = face.vertices[0] as usize;
                 let v1 = face.vertices[1] as usize;
 
-                vor_lines.push(geometry::Line {
+                vor_lines.push(BV::Line {
                     start: vor_vertices[v0],
                     end: vor_vertices[v1],
                 });
@@ -417,7 +406,7 @@ fn parse_input(
         }
     }
     // save the unused vertices as points
-    let vor_vertices: Vec<geometry::Point<i64>> = vor_vertices
+    let vor_vertices: Vec<BV::Point<i64>> = vor_vertices
         .into_iter()
         .enumerate()
         .filter(|x| !used_vertices.get_f(x.0))
@@ -441,10 +430,12 @@ fn voronoi(
 ) -> Result<PB_Model, TBError> {
     let (vor_vertices, vor_lines, vor_aabb2, inverted_transform) =
         parse_input(input_pb_model, cmd_arg_max_voronoi_dimension)?;
-    let mut vb = VB::Builder::default();
-    vb.with_vertices(vor_vertices.iter())?;
-    vb.with_segments(vor_lines.iter())?;
-    let vor_diagram = vb.build()?;
+    let vor_diagram = {
+        BV::Builder::default()
+            .with_vertices(vor_vertices.iter())?
+            .with_segments(vor_lines.iter())?
+            .build()?
+    };
     //println!("diagram:{:?}", vor_diagram);
     println!("aabb2:{:?}", vor_aabb2);
     let mut diagram_helper = DiagramHelper {
@@ -487,7 +478,7 @@ fn build_output(
                 };
                 let key = transmute_to_u64(&v0);
                 let _ = new_vertex_map.entry(key).or_insert_with(|| p.0);
-                let v = inverted_transform.transform_point(super::xy_to_3d(&cgmath::Point2 {
+                let v = inverted_transform.transform_point(type_utils::xy_to_3d(&cgmath::Point2 {
                     x: p.1.x as f64,
                     y: p.1.y as f64,
                 }));
@@ -517,7 +508,7 @@ fn build_output(
                 y: v0.y as f64,
             };
             let key = transmute_to_u64(&v0);
-            let v0 = inverted_transform.transform_point(super::xy_to_3d(&v0));
+            let v0 = inverted_transform.transform_point(type_utils::xy_to_3d(&v0));
             let n = new_vertex_map.entry(key).or_insert_with(|| {
                 let rv = vertices_2d.len();
                 vertices_2d.push(PB_Vertex {
@@ -535,7 +526,7 @@ fn build_output(
                 y: v1.y as f64,
             };
             let key = transmute_to_u64(&v1);
-            let v1 = inverted_transform.transform_point(super::xy_to_3d(&v1));
+            let v1 = inverted_transform.transform_point(type_utils::xy_to_3d(&v1));
             let n = new_vertex_map.entry(key).or_insert_with(|| {
                 let rv = vertices_2d.len();
                 vertices_2d.push(PB_Vertex {
@@ -571,7 +562,8 @@ fn build_output(
     Ok(model)
 }
 
-pub fn command(
+/// Run the voronoi command
+pub(crate) fn command(
     a_command: PB_Command,
     options: HashMap<String, String>,
 ) -> Result<PB_Reply, TBError> {
