@@ -1,14 +1,10 @@
-use crate::toxicblend_pb::Command as PB_Command;
-use crate::toxicblend_pb::Face as PB_Face;
-use crate::toxicblend_pb::KeyValuePair as PB_KeyValuePair;
-use crate::toxicblend_pb::Model as PB_Model;
-use crate::toxicblend_pb::Reply as PB_Reply;
-use crate::toxicblend_pb::Vertex as PB_Vertex;
-use crate::{GrowingVob, TBError};
-use boostvoronoi::builder as VB;
-use boostvoronoi::diagram as VD;
-use boostvoronoi::geometry;
-use cgmath::{EuclideanSpace, SquareMatrix, Transform, UlpsEq};
+use crate::{
+    type_utils, GrowingVob, PB_Command, PB_Face, PB_KeyValuePair, PB_Model, PB_Reply, PB_Vertex,
+    TBError,
+};
+
+use boostvoronoi as BV;
+use cgmath::{EuclideanSpace, MetricSpace, SquareMatrix, Transform, UlpsEq};
 use itertools::Itertools;
 use linestring::linestring_2d::{Aabb2, VoronoiParabolicArc};
 use std::collections::HashMap;
@@ -128,9 +124,9 @@ impl DiagramHelperRw {
 /// Helper structs that build PB buffer from Diagram
 /// This construct contains the read-only items
 struct DiagramHelperRo {
-    diagram: VD::Diagram<i64, f64>,
-    vertices: Vec<geometry::Point<i64>>,
-    segments: Vec<geometry::Line<i64>>,
+    diagram: BV::Diagram<f64>,
+    vertices: Vec<BV::Point<i64>>,
+    segments: Vec<BV::Line<i64>>,
     //aabb: Aabb2<f64>,
     // this list uses the diagram::Edge id as index
     rejected_edges: vob::Vob<u32>,
@@ -144,12 +140,12 @@ impl DiagramHelperRo {
     /// Retrieves a point from the voronoi input in the order it was presented to
     /// the voronoi builder
     #[inline(always)]
-    fn retrieve_point(&self, cell_id: VD::CellIndex) -> Result<geometry::Point<i64>, TBError> {
+    fn retrieve_point(&self, cell_id: BV::CellIndex) -> Result<BV::Point<i64>, TBError> {
         let (index, cat) = self.diagram.get_cell(cell_id)?.get().source_index_2();
         Ok(match cat {
-            VD::SourceCategory::SinglePoint => self.vertices[index],
-            VD::SourceCategory::SegmentStart => self.segments[index - self.vertices.len()].start,
-            VD::SourceCategory::Segment | VD::SourceCategory::SegmentEnd => {
+            BV::SourceCategory::SinglePoint => self.vertices[index],
+            BV::SourceCategory::SegmentStart => self.segments[index - self.vertices.len()].start,
+            BV::SourceCategory::Segment | BV::SourceCategory::SegmentEnd => {
                 self.segments[index - self.vertices.len()].end
             }
         })
@@ -158,7 +154,7 @@ impl DiagramHelperRo {
     /// Retrieves a segment from the voronoi input in the order it was presented to
     /// the voronoi builder
     #[inline(always)]
-    fn retrieve_segment(&self, cell_id: VD::CellIndex) -> Result<&geometry::Line<i64>, TBError> {
+    fn retrieve_segment(&self, cell_id: BV::CellIndex) -> Result<&BV::Line<i64>, TBError> {
         let cell = self.diagram.get_cell(cell_id)?.get();
         let index = cell.source_index() - self.vertices.len();
         Ok(&self.segments[index])
@@ -170,7 +166,7 @@ impl DiagramHelperRo {
     /// intersect with the segment that created the edge. So we need to re-create it.
     /// Secondary edges can also be half internal and half external i.e. the two vertices may
     /// be on opposite sides of the inside/outside boundary.
-    fn convert_secondary_edge(&self, edge: &VD::Edge<i64, f64>) -> Result<Vec<[f64; 3]>, TBError> {
+    fn convert_secondary_edge(&self, edge: &BV::Edge) -> Result<Vec<[f64; 3]>, TBError> {
         let edge_id = edge.id();
         let edge_twin_id = self.diagram.edge_get_twin(edge_id)?;
         let cell_id = self.diagram.edge_get_cell(edge_id)?;
@@ -253,19 +249,12 @@ impl DiagramHelperRo {
                 samples.push([start_point.x, start_point.y, start_point.z]);
             } else {
                 let z_comp = if cell.contains_point() {
-                    -linestring::linestring_2d::distance_to_point_squared(
-                        &cell_point,
-                        &cgmath::Point2 {
-                            x: start_point.x,
-                            y: start_point.y,
-                        },
-                    )
-                    .sqrt()
+                    -cell_point.distance(cgmath::Point2::new(start_point.x, start_point.y))
                 } else {
                     -linestring::linestring_2d::distance_to_line_squared_safe(
-                        &segment.start,
-                        &segment.end,
-                        &cgmath::Point2 {
+                        segment.start,
+                        segment.end,
+                        cgmath::Point2 {
                             x: start_point.x,
                             y: start_point.y,
                         },
@@ -283,22 +272,12 @@ impl DiagramHelperRo {
                 samples.push([end_point.x, end_point.y, end_point.z]);
             } else {
                 let z_comp = if cell.contains_point() {
-                    -linestring::linestring_2d::distance_to_point_squared(
-                        &cell_point,
-                        &cgmath::Point2 {
-                            x: end_point.x,
-                            y: end_point.y,
-                        },
-                    )
-                    .sqrt()
+                    -cell_point.distance(cgmath::Point2::new(end_point.x, end_point.y))
                 } else {
                     -linestring::linestring_2d::distance_to_line_squared_safe(
-                        &segment.start,
-                        &segment.end,
-                        &cgmath::Point2 {
-                            x: end_point.x,
-                            y: end_point.y,
-                        },
+                        segment.start,
+                        segment.end,
+                        cgmath::Point2::new(end_point.x, end_point.y),
                     )
                     .sqrt()
                 };
@@ -314,7 +293,7 @@ impl DiagramHelperRo {
     /// todo: try to consolidate code with convert_secondary_edge()
     fn convert_edge(
         &self,
-        edge: &VD::Edge<i64, f64>,
+        edge: &BV::Edge,
         discretization_dist: f64,
     ) -> Result<Vec<[f64; 3]>, TBError> {
         let edge_id = edge.id();
@@ -327,10 +306,8 @@ impl DiagramHelperRo {
         } else {
             self.retrieve_segment(cell_id)?
         };
-        let vertex0 = edge.vertex0();
-        let vertex1 = self.diagram.edge_get_vertex1(edge_id)?;
 
-        let (start_point, startpoint_is_internal) = if let Some(vertex0) = vertex0 {
+        let (start_point, startpoint_is_internal) = if let Some(vertex0) = edge.vertex0() {
             let vertex0 = self.diagram.vertex_get(vertex0)?.get();
 
             let start_point = if vertex0.is_site_point() {
@@ -358,30 +335,31 @@ impl DiagramHelperRo {
             )));
         };
 
-        let (end_point, end_point_is_internal) = if let Some(vertex1) = vertex1 {
-            let vertex1 = self.diagram.vertex_get(vertex1)?.get();
+        let (end_point, end_point_is_internal) =
+            if let Some(vertex1) = self.diagram.edge_get_vertex1(edge_id)? {
+                let vertex1 = self.diagram.vertex_get(vertex1)?.get();
 
-            let end_point = if vertex1.is_site_point() {
-                cgmath::Point3 {
-                    x: vertex1.x(),
-                    y: vertex1.y(),
-                    z: 0.0,
-                }
+                let end_point = if vertex1.is_site_point() {
+                    cgmath::Point3 {
+                        x: vertex1.x(),
+                        y: vertex1.y(),
+                        z: 0.0,
+                    }
+                } else {
+                    cgmath::Point3 {
+                        x: vertex1.x(),
+                        y: vertex1.y(),
+                        z: f64::NAN,
+                    }
+                };
+                (end_point, self.internal_vertices.get_f(vertex1.get_id().0))
             } else {
-                cgmath::Point3 {
-                    x: vertex1.x(),
-                    y: vertex1.y(),
-                    z: f64::NAN,
-                }
+                return Err(TBError::InternalError(format!(
+                    "Edge vertex1 could not be found. {}:{}",
+                    file!(),
+                    line!()
+                )));
             };
-            (end_point, self.internal_vertices.get_f(vertex1.get_id().0))
-        } else {
-            return Err(TBError::InternalError(format!(
-                "Edge vertex1 could not be found. {}:{}",
-                file!(),
-                line!()
-            )));
-        };
 
         let cell_point = if cell.contains_point() {
             self.retrieve_point(cell_id)?
@@ -425,19 +403,12 @@ impl DiagramHelperRo {
                     samples.push([start_point.x, start_point.y, start_point.z]);
                 } else {
                     let z_comp = if cell.contains_point() {
-                        -linestring::linestring_2d::distance_to_point_squared(
-                            &cell_point,
-                            &cgmath::Point2 {
-                                x: start_point.x,
-                                y: start_point.y,
-                            },
-                        )
-                        .sqrt()
+                        -cell_point.distance(cgmath::Point2::new(start_point.x, start_point.y))
                     } else {
                         -linestring::linestring_2d::distance_to_line_squared_safe(
-                            &segment.start,
-                            &segment.end,
-                            &cgmath::Point2 {
+                            segment.start,
+                            segment.end,
+                            cgmath::Point2 {
                                 x: start_point.x,
                                 y: start_point.y,
                             },
@@ -453,22 +424,12 @@ impl DiagramHelperRo {
                     samples.push([end_point.x, end_point.y, end_point.z]);
                 } else {
                     let z_comp = if cell.contains_point() {
-                        -linestring::linestring_2d::distance_to_point_squared(
-                            &cell_point,
-                            &cgmath::Point2 {
-                                x: end_point.x,
-                                y: end_point.y,
-                            },
-                        )
-                        .sqrt()
+                        -cell_point.distance(cgmath::Point2::new(end_point.x, end_point.y))
                     } else {
                         -linestring::linestring_2d::distance_to_line_squared_safe(
-                            &segment.start,
-                            &segment.end,
-                            &cgmath::Point2 {
-                                x: end_point.x,
-                                y: end_point.y,
-                            },
+                            segment.start,
+                            segment.end,
+                            cgmath::Point2::new(end_point.x, end_point.y),
                         )
                         .sqrt()
                     };
@@ -707,8 +668,8 @@ fn parse_input(
     cmd_arg_max_voronoi_dimension: f64,
 ) -> Result<
     (
-        Vec<geometry::Point<i64>>,
-        Vec<geometry::Line<i64>>,
+        Vec<BV::Point<i64>>,
+        Vec<BV::Line<i64>>,
         Aabb2<f64>,
         cgmath::Matrix4<f64>,
     ),
@@ -716,11 +677,11 @@ fn parse_input(
 > {
     let mut aabb = linestring::linestring_3d::Aabb3::<f64>::default();
     for v in input_pb_model.vertices.iter() {
-        aabb.update_point(&cgmath::Point3::new(v.x as f64, v.y as f64, v.z as f64))
+        aabb.update_point(cgmath::Point3::new(v.x as f64, v.y as f64, v.z as f64))
     }
 
     let (plane, transform, vor_aabb)= centerline::get_transform_relaxed(
-        &aabb,
+        aabb,
         cmd_arg_max_voronoi_dimension,
         super::EPSILON,
         f64::default_max_ulps(),
@@ -739,17 +700,17 @@ fn parse_input(
     println!("voronoi: data was in plane:{:?} aabb:{:?}", plane, aabb);
     //println!("input Lines:{:?}", input_pb_model.vertices);
 
-    let mut vor_lines = Vec::<geometry::Line<i64>>::with_capacity(input_pb_model.faces.len());
-    let vor_vertices: Vec<geometry::Point<i64>> = input_pb_model
+    let mut vor_lines = Vec::<BV::Line<i64>>::with_capacity(input_pb_model.faces.len());
+    let vor_vertices: Vec<BV::Point<i64>> = input_pb_model
         .vertices
         .iter()
         .map(|vertex| {
-            let p = super::xy_to_2d(&transform.transform_point(cgmath::Point3 {
+            let p = type_utils::xy_to_2d(&transform.transform_point(cgmath::Point3 {
                 x: vertex.x,
                 y: vertex.y,
                 z: vertex.z,
             }));
-            geometry::Point {
+            BV::Point {
                 x: p.x as i64,
                 y: p.y as i64,
             }
@@ -764,7 +725,7 @@ fn parse_input(
                 let v0 = face.vertices[0] as usize;
                 let v1 = face.vertices[1] as usize;
 
-                vor_lines.push(geometry::Line {
+                vor_lines.push(BV::Line {
                     start: vor_vertices[v0],
                     end: vor_vertices[v1],
                 });
@@ -777,7 +738,7 @@ fn parse_input(
         }
     }
     // save the unused vertices as points
-    let vor_vertices: Vec<geometry::Point<i64>> = vor_vertices
+    let vor_vertices: Vec<BV::Point<i64>> = vor_vertices
         .into_iter()
         .enumerate()
         .filter(|x| !used_vertices.get_f(x.0))
@@ -788,7 +749,7 @@ fn parse_input(
 
 /// from the list of rejected edges, find a list of internal (non-rejected) vertices.
 fn find_internal_vertices(
-    diagram: &VD::Diagram<i64, f64>,
+    diagram: &BV::Diagram<f64>,
     rejected_edges: &vob::Vob<u32>,
 ) -> Result<vob::Vob<u32>, TBError> {
     let mut internal_vertices = vob::Vob::<u32>::fill(diagram.vertices().len());
@@ -828,10 +789,12 @@ fn voronoi_mesh(
 ) -> Result<PB_Model, TBError> {
     let (vor_vertices, vor_lines, vor_aabb2, inverted_transform) =
         parse_input(input_pb_model, cmd_arg_max_voronoi_dimension)?;
-    let mut vb = VB::Builder::default();
-    vb.with_vertices(vor_vertices.iter())?;
-    vb.with_segments(vor_lines.iter())?;
-    let vor_diagram = vb.build()?;
+    let vor_diagram = {
+        BV::Builder::default()
+            .with_vertices(vor_vertices.iter())?
+            .with_segments(vor_lines.iter())?
+            .build()?
+    };
     let discretization_dist = {
         let max_dist = vor_aabb2.get_high().unwrap() - vor_aabb2.get_low().unwrap();
         let max_dist = max_dist.x.max(max_dist.y);
@@ -860,7 +823,8 @@ fn voronoi_mesh(
     })
 }
 
-pub fn command(
+/// Run the voronoi_mesh command
+pub(crate) fn command(
     a_command: PB_Command,
     options: HashMap<String, String>,
 ) -> Result<PB_Reply, TBError> {
